@@ -5,11 +5,11 @@ class Backup(base_api_core.Core):
     def __init__(self, ip_address, port, username, password, secure=False, cert_verify=False, dsm_version=7, debug=True, otp_code=None):
         super(Backup, self).__init__(ip_address, port, username, password, secure, cert_verify, dsm_version, debug, otp_code)
 
-    def backup_repository_get(self):
+    def backup_repository_get(self, taskid):
         api_name = 'SYNO.Backup.Repository'
         info = self.gen_list[api_name]
         api_path = info['path']
-        req_param = {'version': info['minVersion'], 'method': 'get'}
+        req_param = {'version': info['minVersion'], 'method': 'get', 'task_id': taskid}
 
         return self.request_data(api_name, api_path, req_param)
 
@@ -29,19 +29,19 @@ class Backup(base_api_core.Core):
 
         return self.request_data(api_name, api_path, req_param)
 
-    def backup_task_status(self):
+    def backup_task_status(self, taskid):
         api_name = 'SYNO.Backup.Task'
         info = self.gen_list[api_name]
         api_path = info['path']
-        req_param = {'version': info['minVersion'], 'method': 'status'}
+        req_param = {'version': info['minVersion'], 'method': 'status', 'task_id': taskid}
 
         return self.request_data(api_name, api_path, req_param)
 
-    def backup_task_get(self):
+    def backup_task_get(self, taskid):
         api_name = 'SYNO.Backup.Task'
         info = self.gen_list[api_name]
         api_path = info['path']
-        req_param = {'version': info['minVersion'], 'method': 'get'}
+        req_param = {'version': info['minVersion'], 'method': 'get', 'task_id': taskid}
 
         return self.request_data(api_name, api_path, req_param)
 
@@ -53,7 +53,7 @@ class Backup(base_api_core.Core):
 
         return self.request_data(api_name, api_path, req_param)
 
-    def vault_target_list(self):
+    def vault_target_list(self):  # TODO not working
         api_name = 'SYNO.Backup.Service.VersionBackup.Target'
         info = self.gen_list[api_name]
         api_path = info['path']
